@@ -9,7 +9,6 @@ class Jokes:
         self.http = urllib3.PoolManager()
         self.info = self.http.request('GET', "https://sv443.net/jokeapi/v2/info")
         self.info = data = json.loads(self.info.data.decode('utf-8'))["jokes"]
-        print("Sv443's JokeAPI")
 
     def build_request(
         self,
@@ -159,7 +158,9 @@ class Jokes:
         if auth_token:
             returns.append({"Token-Valid": bool(int(re.split(r"Token-Valid", headers)[1][4]))})
 
-        return returns
+        if len(returns) > 1:
+            return returns
+        return returns[0]
 
     def get_joke(
         self,
